@@ -6,14 +6,26 @@ import click
 from click_shell import shell
 
 # Owned Libraries
-from z2n import __z2n__
-from z2n import __plt__
 from z2n import __docs__
 from z2n import __version__
 
+# Instance of the Plot Object
 from z2n.plot import Plot
 figure = Plot()
 
+# Variables to display on prompt
+
+__z2n__ = f'''
+        Z2n Software ({__version__}), a python program for periodograms analysis.
+        Copyright (C) 2020, and MIT License, by Yohan Alexander [UFS].
+        Type "help" for more information or "docs" for documentation.
+        '''
+
+__plt__ = f'''
+        Interactive plotting window of the Z2n Software ({__version__}).
+        Type "help" for more information.
+        '''
+
 
 @click.version_option(prog_name='Z2n Software', version=__version__)
 @shell(prompt=click.style('(z2n) >>> ', fg='blue', bold=True), intro=__z2n__)
@@ -69,13 +81,6 @@ def plt() -> None:
     """Open the interactive periodogram plotting window."""
 
 
-@plt.command()
-def lines() -> None:
-    """Change parameter lines on the figure."""
-    figure.plot_frequency()
-    figure.plot_bandwidth()
-
-
 @plt.command()
 def title() -> None:
     """Change the title on the figure."""
