@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # Generic/Built-in
+import uuid
+import pathlib
 import tempfile
 
 # Other Libraries
@@ -35,6 +37,8 @@ class Series:
     > An arrray that represents the frequency bins.
     * `z2n : np.array`
     > An arrray that represents the periodogram.
+    * `harmonics : int`
+    > An integer that represents the number of harmonics.
     * `oversample : int`
     > An integer that represents the oversample factor.
     * `fmin : float`
@@ -43,8 +47,8 @@ class Series:
     > A float that represents the maximum frequency.
     * `delta : float`
     > A float that represents the frequency steps.
-    * `observation : float`
-    > A float that represents the observation period.
+    * `exposure : float`
+    > A float that represents the exposure period.
     * `sampling : float`
     > A float that represents the sampling rate.
     * `potency : float`
@@ -53,16 +57,12 @@ class Series:
     > A float that represents the peak frequency.
     * `period : float`
     > A float that represents the peak period.
-    * `error : float`
+    * `errorf : float`
     > A float that represents the frequency uncertainty.
-    * `noise : float`
+    * `errorp : float`
     > A float that represents the period uncertainty.
     * `pulsed : float`
     > A float that represents the pulsed fraction.
-    * `forest : float`
-    > A float that represents the potency uncertainty.
-    * `bandwidth : float`
-    > A float that represents the bandwidth potency.
 
     Methods
     -------
@@ -76,19 +76,20 @@ class Series:
         self.time = np.array([])
         self.bins = np.array([])
         self.z2n = np.array([])
+        self.gaussx = np.array([])
+        self.gaussy = np.array([])
         self.fmin = 0
         self.fmax = 0
         self.delta = 0
+        self.harmonics = 0
         self.oversample = 0
-        self.observation = 0
+        self.exposure = 0
         self.sampling = 0
         self.potency = 0
-        self.forest = 0
-        self.bandwidth = 0
         self.frequency = 0
-        self.error = 0
+        self.errorf = 0
         self.period = 0
-        self.noise = 0
+        self.errorp = 0
         self.pulsed = 0
 
     def get_bak(self) -> str:
@@ -148,12 +149,11 @@ class Series:
         """Change the time series."""
         flag = 0
         if not self.load_file():
-            self.time = self.time.astype(self.time.dtype.name)
             click.secho('Time series set.', fg='green')
-            self.set_observation()
+            self.set_exposure()
             self.set_sampling()
             self.get_time()
-            self.get_observation()
+            self.get_exposure()
             self.get_sampling()
         else:
             flag = 1
@@ -167,24 +167,21 @@ class Series:
     def set_bins(self) -> int:
         """Change the frequency bins."""
         flag = 1
+        click.secho("The frequency bins are needed (Hz).", fg='yellow')
         if self.bins:
             self.set_delta()
-            self.get_delta()
-        elif click.confirm("Do you want to use the Nyquist frequency"):
+        elif click.confirm("Use the Nyquist rate as the minimum frequency"):
             self.fmin = self.sampling * 2
             self.set_fmax()
             self.set_oversample()
-            self.delta = 1 / (self.oversample * self.observation)
-            self.get_fmin()
-            self.get_fmax()
-            self.get_delta()
+            self.delta = 1 / (self.oversample * self.exposure)
         else:
             self.set_fmin()
             self.set_fmax()
             self.set_delta()
-            self.get_fmin()
-            self.get_fmax()
-            self.get_delta()
+        self.get_fmin()
+        self.get_fmax()
+        self.get_delta()
         block = (self.fmax - self.fmin) / np.array(self.delta)
         nbytes = np.array(self.delta).dtype.itemsize * block
         click.secho(
@@ -194,6 +191,7 @@ class Series:
                 self.bins = np.arange(self.fmin, self.fmax, self.delta)
                 click.secho('Frequency bins set.', fg='green')
                 self.get_bins()
+                self.set_harmonics()
                 flag = 0
             else:
                 click.secho("Not enough memory available.", fg='red')
@@ -207,13 +205,17 @@ class Series:
 
     def set_periodogram(self) -> None:
         """Change the periodogram."""
+        pathlib.Path('z2n').mkdir(parents=True, exist_ok=True)
         self.time = np.array(self.time)
         self.bins = np.array(self.bins)
         self.z2n = np.zeros(self.bins.size)
         stats.periodogram(self)
         click.secho('Periodogram calculated.', fg='green')
         self.set_bak()
-        # self.get_bak()
+        self.output = 'z2n/' + str(uuid.uuid4().hex)
+        file.save_ascii(self)
+        file.save_fits(self)
+        click.secho(f"Periodogram saved at {self.output}", fg='green')
 
     def get_fmin(self) -> float:
         """Return the minimum frequency."""
@@ -255,30 +257,40 @@ class Series:
         self.oversample = click.prompt("Oversample factor", type=int)
         click.secho('Oversample factor set.', fg='green')
 
-    def get_observation(self) -> float:
-        """Return the period of observation."""
-        click.secho(f"Exposure time: {self.observation} s", fg='cyan')
-        return self.observation
+    def get_harmonics(self) -> int:
+        """Return the number of harmonics."""
+        click.secho(f"Number of harmonics: {self.harmonics}", fg='cyan')
+        return self.harmonics
 
-    def set_observation(self) -> None:
-        """Change the period of observation."""
-        stats.observation(self)
+    def set_harmonics(self) -> None:
+        """Change the number of harmonics."""
+        self.harmonics = click.prompt("Number of harmonics", type=int)
+        click.secho('Harmonics set.', fg='green')
+
+    def get_exposure(self) -> float:
+        """Return the period of exposure."""
+        click.secho(f"Exposure time: {self.exposure} s", fg='cyan')
+        return self.exposure
+
+    def set_exposure(self) -> None:
+        """Change the period of exposure."""
+        stats.exposure(self)
         click.secho('Exposure time set.', fg='green')
 
     def get_sampling(self) -> float:
         """Return the sampling rate."""
-        click.secho(f"Sampling frequency: {self.sampling} Hz", fg='cyan')
+        click.secho(f"Sampling rate: {self.sampling} Hz", fg='cyan')
         return self.sampling
 
     def set_sampling(self) -> None:
         """Change the sampling rate."""
         stats.sampling(self)
-        click.secho('Sampling frequency set.', fg='green')
+        click.secho('Sampling rate set.', fg='green')
 
     def get_potency(self) -> float:
         """Return the peak potency."""
         click.secho(
-            f"Peak potency: {self.potency} +/- {self.forest}", fg='cyan')
+            f"Peak potency: {self.potency}", fg='cyan')
         return self.potency
 
     def set_potency(self) -> None:
@@ -289,7 +301,7 @@ class Series:
     def get_frequency(self) -> float:
         """Return the peak frequency."""
         click.secho(
-            f"Peak frequency: {self.frequency} +/- {self.error} Hz", fg='cyan')
+            f"Peak frequency: {self.frequency} +/- {self.errorf} Hz", fg='cyan')
         return self.frequency
 
     def set_frequency(self) -> None:
@@ -300,7 +312,7 @@ class Series:
     def get_period(self) -> float:
         """Return the peak period."""
         click.secho(
-            f"Peak period: {self.period} +/- {self.noise} s", fg='cyan')
+            f"Peak period: {self.period} +/- {self.errorp} s", fg='cyan')
         return self.period
 
     def set_period(self) -> None:
@@ -318,42 +330,22 @@ class Series:
         stats.pfraction(self)
         click.secho('Pulsed fraction set.', fg='green')
 
-    def get_forest(self) -> float:
-        """Return the potency uncertainty."""
-        click.secho(f"Potency uncertainty: {self.forest}", fg='cyan')
-        return self.forest
-
-    def set_forest(self) -> None:
-        """Change the forest potency."""
-        stats.forest(self)
-        click.secho('Potency uncertainty set.', fg='green')
-
-    def get_bandwidth(self) -> float:
-        """Return the bandwidth potency."""
-        click.secho(f"Bandwidth: {self.bandwidth}", fg='cyan')
-        return self.bandwidth
-
-    def set_bandwidth(self) -> None:
-        """Change the bandwidth potency."""
-        stats.bandwidth(self)
-        click.secho('Bandwidth set.', fg='green')
-
-    def get_error(self) -> float:
+    def get_errorf(self) -> float:
         """Return the uncertainty of the frequency."""
-        click.secho(f"Frequency Uncertainty: {self.error} +/-", fg='cyan')
-        return self.error
+        click.secho(f"Frequency Uncertainty: {self.errorf} +/-", fg='cyan')
+        return self.errorf
 
-    def set_error(self) -> None:
+    def set_errorf(self) -> None:
         """Return the uncertainty of the frequency."""
         stats.error(self)
         click.secho('Frequency uncertainty set.', fg='green')
 
-    def get_noise(self) -> float:
+    def get_errorp(self) -> float:
         """Return the uncertainty of the period."""
-        click.secho(f"Period Uncertainty: {self.noise} +/-", fg='cyan')
-        return self.noise
+        click.secho(f"Period Uncertainty: {self.errorp} +/-", fg='cyan')
+        return self.errorp
 
-    def set_noise(self) -> None:
+    def set_errorp(self) -> None:
         """Return the uncertainty of the period."""
         stats.error(self)
         click.secho('Period uncertainty set.', fg='green')
@@ -410,20 +402,8 @@ class Series:
         self.get_potency()
         self.get_frequency()
         self.get_period()
-        # self.get_forest()
-        # self.get_error()
-        # self.get_noise()
-        self.get_bandwidth()
         self.get_pfraction()
 
     def set_parameters(self) -> None:
         """Change the parameters used on the statistic."""
-        # self.set_potency()
-        # self.set_frequency()
-        # self.set_period()
-        # self.set_forest()
-        # self.set_error()
-        # self.set_noise()
-        # self.set_bandwidth()
-        # self.set_pfraction()
         stats.error(self)
