@@ -12,9 +12,9 @@ import matplotlib.pyplot as plt
 
 
 @jit(forceobj=True, parallel=True, fastmath=True)
-def observation(series) -> None:
+def exposure(series) -> None:
     """
-    Calculate the period of observation.
+    Calculate the period of exposure.
 
     Parameters
     ----------
@@ -27,7 +27,7 @@ def observation(series) -> None:
     """
     last = np.max(series.time)
     first = np.min(series.time)
-    series.observation = last - first
+    series.exposure = last - first
 
 
 @jit(forceobj=True, parallel=True, fastmath=True)
@@ -44,11 +44,11 @@ def sampling(series) -> None:
     -------
     None
     """
-    series.sampling = (1 / series.observation)
+    series.sampling = (1 / series.exposure)
 
 
 @jit(nopython=True, parallel=True, fastmath=True)
-def phase(times: np.array, freq: float) -> np.array:
+def phase(times: np.array, freq: float, harm: int) -> np.array:
     """
     Calculate the phase values.
 
@@ -58,6 +58,8 @@ def phase(times: np.array, freq: float) -> np.array:
         An array that represents the times.
     freq : float
         A float that represents the frequency.
+    harm : int
+        A int that represents the harmonics.
 
     Returns
     -------
@@ -66,7 +68,7 @@ def phase(times: np.array, freq: float) -> np.array:
     """
     values = times * freq
     values = values - np.floor(values)
-    values = values * 2 * np.pi
+    values = values * 2 * np.pi * harm
     return values
 
 
@@ -147,7 +149,7 @@ def square(value: float) -> float:
 
 
 @jit(nopython=True, parallel=False, fastmath=True)
-def spectrum(sin: float, cos: float) -> float:
+def power(sin: float, cos: float) -> float:
     """
     Calculate the Z2n potency value.
 
@@ -168,7 +170,7 @@ def spectrum(sin: float, cos: float) -> float:
 
 
 @jit(nopython=True, parallel=False, fastmath=True)
-def z2n(times: np.array, freq: float) -> float:
+def z2n(times: np.array, freq: float, harm: int) -> float:
     """
     Calculate the Z2n potency value.
 
@@ -176,29 +178,31 @@ def z2n(times: np.array, freq: float) -> float:
         An array that represents the times.
     freq : float
         A float that represents the frequency.
+    harm : int
+        A int that represents the harmonics.
 
     Returns
     -------
     value : float
         A float that represents the Z2n potency.
     """
-    phases = phase(times, freq)
+    phases = phase(times, freq, harm)
     sin = summation(sine(phases))
     cos = summation(cosine(phases))
-    value = spectrum(square(sin), square(cos))
+    value = power(square(sin), square(cos))
     return value
 
 
 @jit(nopython=True, parallel=True, fastmath=True)
-def normalization(spec: np.array, norm: float) -> np.array:
+def normalization(spectrum: np.array, normal: float) -> np.array:
     """
     Calculate the normalization values.
 
     Parameters
     ----------
-    spec : np.array
+    spectrum : np.array
         An array that represents the z2n values.
-    norm : float
+    normal : float
         A float that represents the normalization.
 
     Returns
@@ -206,10 +210,33 @@ def normalization(spec: np.array, norm: float) -> np.array:
     values : np.array
         An array that represents the normalized values.
     """
-    values = spec * norm
+    values = spectrum * normal
     return values
 
 
+@jit(nopython=True, parallel=True, fastmath=True)
+def harmonics(time: np.array, freq: float, harm: int) -> np.array:
+    """
+    Calculate the Z2n harmonics.
+
+    Parameters
+    ----------
+    series : Series
+        A time series object.
+    harm : int
+        A int that represents the harmonics.
+
+    Returns
+    -------
+    None
+    """
+    values = np.zeros(harm)
+    for harmonic in range(harm):
+        values[harmonic] = z2n(time, freq, harmonic + 1)
+    value = summation(values)
+    return value
+
+
 @jit(forceobj=True, parallel=True, fastmath=True)
 def periodogram(series) -> None:
     """
@@ -224,11 +251,10 @@ def periodogram(series) -> None:
     -------
     None
     """
-    for freq in trange(
-            series.bins.size, desc=click.style(
-                'Calculating the periodogram', fg='yellow')):
-        series.z2n[freq] = series.z2n[freq] + \
-            z2n(series.time, series.bins[freq])
+    for freq in trange(series.bins.size, desc=click.style(
+            'Calculating the periodogram', fg='yellow')):
+        series.z2n[freq] = harmonics(
+            series.time, series.bins[freq], series.harmonics)
     series.z2n = normalization(series.z2n, (2 / series.time.size))
 
 
@@ -302,57 +328,22 @@ def pfraction(series) -> None:
     series.pulsed = pfrac ** 0.5
 
 
+@jit(nopython=True, parallel=True, fastmath=True)
+def gaussian(x, amplitude, mean, sigma):
+    """Returns a Gaussian like function."""
+    return amplitude * np.exp(-((x - mean) ** 2) / (2 * sigma ** 2))
+
+
 @jit(forceobj=True, parallel=True, fastmath=True)
-def bandwidth(series) -> None:
-    """
-    Calculate the bandwidth.
-
-    Parameters
-    ----------
-    series : Series
-        A time series object.
-
-    Returns
-    -------
-    None
-    """
-    series.bandwidth = series.potency - series.forest
-
-
-def forest(series) -> None:
-    """
-    Calculate the potency uncertainty.
-
-    Parameters
-    ----------
-    series : Series
-        A time series object.
-
-    Returns
-    -------
-    None
-    """
-    click.secho("Select regions to estimate potency uncertainty.", fg='yellow')
-    regions = click.prompt("How many regions", type=int)
-    if regions > 0:
-        means = np.zeros(regions)
-        for region in range(regions):
-            flag = 1
-            while flag:
-                if click.confirm(f"Is the region {region + 1} selected"):
-                    axis = plt.gca().get_xlim()
-                    low = np.where(np.isclose(series.bins, axis[0], 0.1))[0][0]
-                    up = np.where(np.isclose(series.bins, axis[1], 0.1))[0][-1]
-                    means[region] = np.mean(series.z2n[low:up])
-                    flag = 0
-        series.forest = np.mean(means)
-    else:
-        click.secho("No regions to estimate uncertainty.", fg='yellow')
+def fitcurve(function, bins, powerspec, guess):
+    """Fit a input curve function to the data."""
+    return optimize.curve_fit(function, bins, powerspec, guess)
 
 
+# @jit(forceobj=True, parallel=True, fastmath=True)
 def error(series) -> None:
     """
-    Calculate the frequency uncertainty.
+    Calculate the uncertainty.
 
     Parameters
     ----------
@@ -363,87 +354,26 @@ def error(series) -> None:
     -------
     None
     """
-    def sinc(x, amplitude, mean, sigma):
-        gaussian = np.exp(-((x - mean) ** 2) / (2 * sigma ** 2))
-        return amplitude * (np.sinc((x - mean) / sigma)) ** 2 + gaussian
     flag = 1
     click.secho(
-        "Select the peak region to estimate frequency uncertainty.", fg='yellow')
+        "Select the peak region to estimate uncertainty.", fg='yellow')
     while flag:
         if click.confirm("Is the peak region selected"):
             axis = plt.gca().get_xlim()
             low = np.where(np.isclose(series.bins, axis[0], 0.1))[0][0]
             up = np.where(np.isclose(series.bins, axis[1], 0.1))[0][-1]
             mean, sigma = norm.fit(series.bins[low:up])
+            potency(series)
             guess = [series.potency, mean, sigma]
-            popt, _ = optimize.curve_fit(
-                sinc, series.bins[low:up], series.z2n[low:up], guess)
+            popt, _ = fitcurve(
+                gaussian, series.bins[low:up], series.z2n[low:up], guess)
             series.potency = np.absolute(popt[0])
             series.frequency = np.absolute(popt[1])
             period(series)
-            forest(series)
-            series.error = np.absolute(popt[2])
-            series.noise = np.absolute(
-                (1 / (series.frequency + series.error)) - series.period)
-            bandwidth(series)
+            series.errorf = np.absolute(popt[2])
+            series.errorp = np.absolute(
+                (1 / (series.frequency + series.errorf)) - series.period)
             pfraction(series)
-            series.z2n[low:up] = sinc(series.bins[low:up], *popt)
-            # plt.plot(series.bins[low:up], sinc(
-            #    series.bins[low:up], *guess), color='tab:red')
-            # plt.plot(series.bins[low:up], sinc(
-            #    series.bins[low:up], *popt), color='tab:green')
+            series.gaussx = series.bins[low:up]
+            series.gaussy = gaussian(series.bins[low:up], *popt)
             flag = 0
-
-
-def crop(series, temp) -> int:
-    """
-    Crop and recalculate periodogram region.
-
-    Parameters
-    ----------
-    series : Series
-        A time series object.
-
-    Returns
-    -------
-    None
-    """
-    flag = 0
-    flag2 = 1
-    click.secho("This will recalculate the periodogram.", fg='yellow')
-    while flag2:
-        if click.confirm("Is the region selected"):
-            axis = plt.gca().get_xlim()
-            low = np.median(
-                np.where(np.isclose(series.bins, axis[0], 0.1))).astype(int)
-            up = np.median(
-                np.where(np.isclose(series.bins, axis[1], 0.1))).astype(int)
-            temp.fmin = axis[0]
-            temp.fmax = axis[1]
-            temp.bins = 1
-            if not temp.set_bins():
-                temp.time = np.array(series.time)
-                plt.close()
-                temp.set_periodogram()
-                size = (series.bins.size - (up - low)) + temp.bins.size
-                middle = low + temp.bins.size
-                tempx = np.zeros(size)
-                tempy = np.zeros(size)
-                tempx[:low] = series.bins[:low]
-                tempy[:low] = series.z2n[:low]
-                tempx[low:middle] = temp.bins
-                tempy[low:middle] = temp.z2n
-                tempx[middle:] = series.bins[up:]
-                tempy[middle:] = series.z2n[up:]
-                series.bins = tempx
-                series.z2n = tempy
-                series.set_bak()
-                del temp
-                del tempx
-                del tempy
-                flag = 0
-                flag2 = 0
-            else:
-                flag = 1
-                flag2 = 0
-    return flag
